diff --git a/nvdaHelper/remote/winword.cpp b/nvdaHelper/remote/winword.cpp
index d9fa7ac..54b976e 100644
--- a/nvdaHelper/remote/winword.cpp
+++ b/nvdaHelper/remote/winword.cpp
@@ -95,6 +95,9 @@ using namespace std;
 #define wdDISPID_COLUMNS_COUNT 2
 #define wdDISPID_TABLE_ROWS 101
 #define wdDISPID_ROWS_COUNT 2
+#define wdDISPID_PARAGRAPHFORMAT_RIGHTINDENT 106
+#define wdDISPID_PARAGRAPHFORMAT_LEFTINDENT 107
+#define wdDISPID_PARAGRAPHFORMAT_FIRSTLINEINDENT 108
 
 #define wdCommentsStory 4
 
@@ -324,6 +327,16 @@ void generateXMLAttribsForFormatting(IDispatch* pDispatchRange, int startOffset,
 					break;
 				}
 			}
+			float fVal=0.0;
+			if(_com_dispatch_raw_propget(pDispatchParagraphFormat,wdDISPID_PARAGRAPHFORMAT_RIGHTINDENT,VT_R4,&fVal)==S_OK) {
+				formatAttribsStream<<L"right-indent=\"" << fVal <<L"\" ";
+			}
+			if(_com_dispatch_raw_propget(pDispatchParagraphFormat,wdDISPID_PARAGRAPHFORMAT_LEFTINDENT,VT_R4,&fVal)==S_OK) {
+				formatAttribsStream<<L"left-indent=\"" << fVal <<L"\" ";
+			}
+			if(_com_dispatch_raw_propget(pDispatchParagraphFormat,wdDISPID_PARAGRAPHFORMAT_FIRSTLINEINDENT,VT_R4,&fVal)==S_OK) {
+				formatAttribsStream<<L"first-line-indent=\"" << fVal <<L"\" ";
+			}
 		}
 	}
 	if(formatConfig&formatConfig_reportLists) {
@@ -373,8 +386,9 @@ void generateXMLAttribsForFormatting(IDispatch* pDispatchRange, int startOffset,
 				formatAttribsStream<<L"font-name=\""<<fontName<<L"\" ";
 				SysFreeString(fontName);
 			}
-			if((formatConfig&formatConfig_reportFontSize)&&(_com_dispatch_raw_propget(pDispatchFont,wdDISPID_FONT_SIZE,VT_I4,&iVal)==S_OK)) {
-				formatAttribsStream<<L"font-size=\""<<iVal<<L"pt\" ";
+			float fVal=0.0;
+			if((formatConfig&formatConfig_reportFontSize)&&(_com_dispatch_raw_propget(pDispatchFont,wdDISPID_FONT_SIZE,VT_R4,&fVal)==S_OK)) {
+				formatAttribsStream<<L"font-size=\""<<fVal<<L"pt\" ";
 			}
 			if((formatConfig&formatConfig_reportColor)&&(_com_dispatch_raw_propget(pDispatchFont,wdDISPID_FONT_COLOR,VT_I4,&iVal)==S_OK)) {
 				formatAttribsStream<<L"color=\""<<iVal<<L"\" ";
diff --git a/source/speech.py b/source/speech.py
index a5af6fb..5a369ec 100755
--- a/source/speech.py
+++ b/source/speech.py
@@ -1129,6 +1129,38 @@ def getFormatFieldSpeech(attrs,attrsCache=None,formatConfig=None,unit=None,extra
 				# Translators: Reported when text has reverted to default alignment.
 				text=_("align default")
 			textList.append(text)
+	fontSize=attrs.get("font-size")
+	fontSizePt = float(fontSize[0:-2]) if fontSize and fontSize[-2:] == "pt" and float(fontSize[0:-2]) > 0.0 else None
+	leftIndent=attrs.get("left-indent")
+	oldLeftIndent=attrsCache.get("left-indent") if attrsCache is not None else None
+	if leftIndent and leftIndent != oldLeftIndent:
+		n = float(leftIndent)
+		if abs(n) < 0.001:
+			textList.append(_("no left indent"))
+		else:
+			s = _("%g characters") % (n / fontSizePt) if fontSizePt else _("%g pt") % n
+			textList.append(_("left indent") + " " + s)
+	firstLineIndent=attrs.get("first-line-indent")
+	oldFirstLineIndent=attrsCache.get("first-line-indent") if attrsCache is not None else None
+	if firstLineIndent and firstLineIndent != oldFirstLineIndent:
+		n = float(firstLineIndent)
+		if -0.001 < n < 0.001:
+			textList.append(_("no paragraph indent"))
+		else:
+			s = _("%g characters") % abs(n / fontSizePt) if fontSizePt else _("%g pt") % abs(n)
+			if n > 0:
+				textList.append(_("paragraph indent") + " " + s)
+			else:
+				textList.append(_("hanging indent") + " " + s)
+	rightIndent=attrs.get("right-indent")
+	oldRightIndent=attrsCache.get("right-indent") if attrsCache is not None else None
+	if rightIndent and rightIndent != oldRightIndent:
+		n = float(rightIndent)
+		if abs(n) < 0.001:
+			textList.append(_("no right indent"))
+		else:
+			s = _("%g characters") % (n / fontSizePt) if fontSizePt else _("%g pt") % n
+			textList.append(_("right indent") + " " + s)
 	if  formatConfig["reportLinks"]:
 		link=attrs.get("link")
 		oldLink=attrsCache.get("link") if attrsCache is not None else None
